"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const net = require("net");
const driverClient_1 = require("./driverClient");
const events_1 = require("events");
const server_1 = require("../server");
class DriverServer {
    constructor() {
        this.clients = new Map();
        this.emitter = new events_1.EventEmitter();
        this.connectIdSeq = 0;
    }
    startRaasServer(port) {
        this.raasServer = new server_1.Server();
        this.raasServer.start(port);
    }
    startSocketServer(port, raasConfig) {
        this.raasConfig = raasConfig;
        this.server = net.createServer(this.connect.bind(this));
        this.emitter.on('clientDiconnected', this.onClientDisconnected);
        this.server.listen(port);
        console.log(`proxy server listening at: ${JSON.stringify(this.server.address())}`);
    }
    connect(c) {
        console.log('driverServer socket connected...');
        const id = String(this.connectIdSeq++);
        const client = new driverClient_1.DriverClient(this.emitter, c, id, this.raasConfig);
        this.clients.set(id, client);
        client.connect();
    }
    onClientDisconnected(client) {
        console.log('driverServer socket disconnected...');
        this.clients.delete(client.id);
    }
}
exports.DriverServer = DriverServer;
const driver = new DriverServer();
const raasHost = process.env.RAAS_HOST || 'localhost';
const raasPort = process.env.RAAS_PORT || 61435;
const driverPort = process.env.DRIVER_PORT || 61436;
driver.startRaasServer(Number(raasPort));
driver.startSocketServer(Number(driverPort), { host: raasHost, port: Number(raasPort) });
//# sourceMappingURL=driverServer.js.map